*This do file generates the dataset used in table "Effect on bank profits"
set more off
clear
set mem 150m
cd "f:\budesktopbackup\data\drtge\ecma_revision
cap log using bankleveldata.log, replace

*****************STRUCTURE OF THE DO FILE
/*
The do file has two parts. First, the branch level data is loaded. This is 
restricted to an early period and then for each firm, the number of branches 
in different regions/categories is calculated. This is later collapsed to the 
firm level, interacted with a DRT variable and used to measure exposure to 
DRT. Next, the data is merged with accounting data to get profits. 
*/ 

*****************PREPARE THE PROWESS ACCOUNTING DATA

insheet using bankaccountingprowess.csv, delimiter("|") clear names
drop cf_from_operating_activitydec199
drop v*
drop cf_from_operating_activ* cf_from_operating_activitydec200
order cf_*

reshape long ymfinance_year months inc_revenue_total inc_sales inc_fin_services inc_exp_recovered exp_total exp_salaries_and_wages exp_staff_training exp_prov_dd_bad_advance exp_total_provisions exp_write_offs exp_bad_debts_write_off exp_bad_debts_woff pat deposits_commercial_banks bank_borr_rbi bank_borr_others tot_net_fixed_asst total_assets loan_advance_nbfcs term_loan_advances short_term_loan_advances advance_others loan_and_advance loan_co_deptl_undertaking securtd_n_oth_loans securities_asst_loans   cf_interest_recd cap_adequacy_ratio movement_gross_npa opening_gross_npa prov_for_npa pbdita pbdpta, i(companyname) j(year) string

gen banks=subinstr(companyname,"'","",.)
replace banks=lower(banks)
replace banks=subinstr(banks," ","",.)
replace banks=subinstr(banks,"-","",.)
replace banks=subinstr(banks,".","",.)

 
gen banksacc=substr(banks,1,10)
encode banks, gen(bankid)

drop if strpos(banks,"gramin")>0 | strpos(banks,"grameen")>0 | strpos(banks,"gramya")>0 | strpos(banks,"rural")>0 | strpos(banks,"grama")>0 | strpos(banks,"dehati")>0 | strpos(banks,"gaon")>0 | strpos(banks,"cooperative")>0 | strpos(banks,"coop")>0 | strpos(banks,"sahakari")>0
 
gen dateold=ymfinance_year
tostring ymfinance_year, replace
gen ymfinance_mth=substr(ymfinance_year,5,2)
gen ymfinance_yr=substr(ymfinance_year,1,4)
destring ymfinance_mth, replace
destring ymfinance_yr, replace
gen yearold=ym(ymfinance_yr,ymfinance_mth)
gen fyear=yofd(dofm(yearold))
drop yearold ymfinance_yr ymfinance_mth

 
 
keep if fyear<=2003 
 

rename exp_compensation_to_employeedec1 expcompemployeedec1
rename exp_compensation_to_employeedec2 expcompemployeedec2

sort bankid fyear
save prowessaccounting, replace

**************PREPARE BANK BRANCH DATA
forvalues i=1/6 {
insheet using bankbranches\branches`i'.csv, clear
save bankbranches\branch`i', replace
}

forvalues i=1/5 { 
append using bankbranches\branch`i' 
} 
save bankbranches\bankbranches, replace 

forvalues i=1/6 {
erase bankbranches\branch`i'.dta
}

use bankbranches\bankbranches, clear


*******FOR ALL NEW STATES, collapse them with the parent state
gen state=.
replace state=1 if statename=="ANDHRA PRADESH"
replace state=2 if statename=="DELHI"
replace state=3 if statename=="GUJARAT"
replace state=4 if statename=="HARYANA"
replace state=5 if statename=="HIMACHAL PRADESH"
replace state=6 if statename=="JAMMU & KASHMIR"
replace state=7 if statename=="BIHAR" | statename=="JHARKHAND"
replace state=8 if statename=="KARNATAKA"
replace state=9 if statename=="MADHYA PRADESH" | statename=="CHHATTISGARH"
replace state=10 if statename=="MAHARASHTRA"
replace state=11 if statename=="PONDICHERRY"
replace state=12 if statename=="RAJASTHAN"
replace state=13 if statename=="TAMIL NADU"
replace state=14 if statename=="UTTAR PRADESH" | statename=="UTTARANCHAL"
replace state=15 if statename=="WEST BENGAL"
replace state=16 if statename=="KERALA"
replace state=17 if statename=="PUNJAB"
*replace state=18 if statename==
replace state=19 if statename=="ASSAM"             
replace state=20 if statename=="GOA"               
replace state=21 if statename=="CHANDIGARH"        
replace state=22 if statename=="DADRA&NAGAR HAVELI"
replace state=23 if statename=="DAMAN & DIU"       
replace state=24 if statename=="ORISSA"            
replace state=25 if statename=="ANDAMAN & NICOBAR" 
replace state=26 if statename=="MEGHALAYA"         
replace state=27 if statename=="MANIPUR"           
replace state=28 if statename=="MIZORAM"           
replace state=29 if statename=="TRIPURA"           
replace state=30 if statename=="ARUNACHAL PRADESH" 
replace state=31 if statename=="NAGALAND"
replace state=32 if statename=="LAKSHADWEEP"
replace state=33 if statename=="SIKKIM"
count if state==.
count if state<.

****NATURE OF BUSINESS CODES BELOW. 2 POSSIBILITIES: (a) only banking business branches are relevant (b) banking + admin branches are relevant b/c admin branches
****handle asset recovery.
*0 	Only Banking Business,
*1 	Banking & Foreign Exchange Business,
*2 	Administration, Banking & Foreign Exchange Business,
*3 	Administration & Banking Business,
*4 	Administration & Foreign Exchange Business,
*5 	Only Foreign Exchange Business,
*6 	Only Administration / Training / etc.
*7 	Non-Scheduled Banks doing Banking Business,

gen branchtaga=1 if natureofbusiness<=3
replace branchtaga=0 if branchtaga~=1
*gen branchtagb=1 if natureofbusiness<=4 | natureofbusiness>=6
*replace branchtagb=0 if branchtagb~=1
*gen branchtagc=1 if natureofbusiness==2 | natureofbusiness==3 | natureofbusiness==4 | natureofbusiness==6
*replace branchtagc=0 if branchtagc~=1
*gen branchtagd=1 if natureofbusiness<=7
*replace branchtagd=0 if branchtagd~=1

****POPULATION GROUP CODE
label def popgroup 1 "rural" 2 "semi-urban" 3 "urban" 4 "metropolitan", add
rename populationgroupcode popgroup
label values popgroup popgroup

gen branchtage=1 if branchtaga==1 & (popgroup==3 | popgroup==4)
replace branchtage=0 if branchtage~=1

gen branchtagf=1 if branchtaga==1 & popgroup==4
replace branchtagf=0 if branchtagf~=1

tostring openingdate, replace
generate x=date(openingdate, "YMD")
format x %td
gen year=yofd(x)

tab year, m
drop x

***WE WANT (A) TO CREATE A BANK-STATE-YEAR LEVEL DATASET OF NUM OF BRANCHES, AND (2) A BANK-STATE LEVEL DATASET OF NUM OF BRANCHES TODAY, AND NUM OF BRANCHES IN 1992.

compress
fillin bankname state year
replace branchtaga=0 if branchtaga~=1
replace branchtage=0 if branchtage~=1
replace branchtagf=0 if branchtagf~=1

bys bankname state: egen minyear=min(year)
gen xa=0 if year==minyear
gen xe=0 if year==minyear
gen xf=0 if year==minyear

bys bankname state: replace xa=xa[_n-1] + branchtaga if year>minyear
bys bankname state: replace xe=xe[_n-1] + branchtage if year>minyear
bys bankname state: replace xf=xf[_n-1] + branchtage if year>minyear

keep if year>=1989
drop _fillin minyear
rename xa conbrancha
rename xe conbranche
rename xf conbranchf

bys bankname state year: egen maxconbrancha=max(conbrancha)
bys bankname state year: egen maxconbranche=max(conbranche)
bys bankname state year: egen maxconbranchf=max(conbranchf)

replace conbrancha=maxconbrancha
replace conbranche=maxconbranche
replace conbranchf=maxconbranchf

drop maxconbrancha maxconbranche maxconbranchf

bys bankname year: egen conbanknra=total(conbrancha)
bys bankname year: egen conbanknre=total(conbranche)
bys bankname year: egen conbanknrf=total(conbranchf)

gen b92=1 if year<=1992
replace b92=0 if b92~=1
gen all=1 if year>1002 | year<=1992

tab populationgroupname
 
***FOR EACH BANK, COUNT THE NUMBER OF BANK BRANCHES. THEN FOR EACH BANK-STATE, COUNT NUM OF BANK BRANCHES.
***in (a) we count only banking branches. in (b) we count banking + admin branches.

foreach v in b92 all {
bys bankworkingcode: egen banknra`v'=total(branchtaga) if `v'==1
replace banknra`v'=0 if banknra`v'==. 
bys bankworkingcode state: egen bankstatea`v'=total(branchtaga) if `v'==1
replace bankstatea`v'=0 if bankstatea`v'==. 
bys bankworkingcode: egen banknre`v'=total(branchtage) if `v'==1
replace banknre`v'=0 if banknre`v'==.
bys bankworkingcode state: egen bankstatee`v'=total(branchtage) if `v'==1
replace bankstatee`v'=0 if bankstatee`v'==. 
bys bankworkingcode: egen banknrf`v'=total(branchtagf) if `v'==1
replace banknrf`v'=0 if banknrf`v'==.
bys bankworkingcode state: egen bankstatef`v'=total(branchtagf) if `v'==1
replace bankstatef`v'=0 if bankstatef`v'==.
}

gen banks=subinstr(bankname,"'","",.)
replace banks=lower(banks)
replace banks=subinstr(banks," ","",.)
replace banks=subinstr(banks,"-","",.)
replace banks=subinstr(banks,".","",.)
duplicates drop banks state year, force

gen     bankid=  1 if banks=="abbankltd"                                      
replace bankid=  2 if banks=="abhyudayacoopbankltd"
replace bankid=  3 if banks=="abnamrobanknv"
replace bankid=  4 if banks=="abudhabicommercialbank" | banks=="abudhabicommercialbankltd"
replace bankid=  5 if banks=="agriculturalfinancecorpnltd"
replace bankid=  6 if banks=="ahmedabadmercantilecooperativebankltd"
replace bankid=  7 if banks=="allahabadbank"
replace bankid=  8 if banks=="americanexpressbankltd"
replace bankid=  9 if banks=="americanexpressintlbankingcorpn"
replace bankid= 10 if banks=="andhrabank"
replace bankid= 11 if banks=="andhrapradeshstatefinancialcorpn"
replace bankid= 12 if banks=="antwerpdiamondbanknv"
replace bankid= 13 if banks=="apexcooperativebank"
replace bankid= 14 if banks=="apmaheshcooperativeurbanbankltd"
replace bankid= 15 if banks=="apnacooperativeurbanbankltd"
replace bankid= 16 if banks=="apnasahakaribankltd"
replace bankid= 17 if banks=="assamfinancialcorpn"
replace bankid= 18 if banks=="assamindustrialdevpcorpnltd"
replace bankid= 19 if banks=="axisbankltd"
replace bankid= 20 if banks=="bankinternationalindonesia" | banks=="bankinternasionalindonesia"
replace bankid= 21 if banks=="bankmuscatalahlialomani" | banks=="bankmuscatinternationalsaog" | banks=="bankmuscatsaog"
replace bankid= 23 if banks=="bankofamericanationaltrust&savingsassociation" | banks=="bankofamericantandsa" | | banks=="bankofamericana"
replace bankid= 24 if banks=="bankofbahrain&kuwaitbsc"
replace bankid= 25 if banks=="bankofbaroda"
replace bankid= 26 if banks=="bankofceylon"
replace bankid= 27 if banks=="bankofindia"
replace bankid= 28 if banks=="bankofmaduraltd[merged]" | banks=="bankofmaduraltd"
replace bankid= 29 if banks=="bankofmaharashtra"
replace bankid= 30 if banks=="bankofnovascotia"
replace bankid= 31 if banks=="bankofpunjabltd[merged]" | banks=="bankofpunjablimited"
replace bankid= 32 if banks=="bankofrajasthanltd"
replace bankid= 33 if banks=="bankoftokyomitsubishiufjltd" | banks=="bankoftokyomitsubishiltd" | banks=="bankoftokyoltd"
replace bankid= 34 if banks=="banquenationaledeparis"
replace bankid= 35 if banks=="barclaysbankplc"
replace bankid= 36 if banks=="bareillycorporationbankltd"
replace bankid= 37 if banks=="benaresstatebankltd[merged]" | banks=="benarasstatebankltd"
replace bankid= 38 if banks=="bhandaricooperativebankltd"
replace bankid= 39 if banks=="bharatcoopbank(mumbai)ltd"
replace bankid= 40 if banks=="bharatoverseasbankltd[merged]" | banks=="bharatoverseasbankltd"
replace bankid= 41 if banks=="bharatsahakaribankltd"
replace bankid= 42 if banks=="biharstatecoopbankltd"
replace bankid= 43 if banks=="bnpparibas"
replace bankid= 44 if banks=="bombaymercantilecoopbankltd"
replace bankid= 45 if banks=="britishbankofthemiddleeast" | banks=="britishbankofmiddleeast"
replace bankid= 46 if banks=="calyonbank"
replace bankid= 47 if banks=="canarabank"
replace bankid= 48 if banks=="capitallocalareabankltd"
replace bankid= 49 if banks=="catholicsyrianbankltd"
replace bankid= 50 if banks=="centralbankofindia"
replace bankid= 51 if banks=="centurionbankofpunjabltd" | banks=="centurionbankltd"
replace bankid= 52 if banks=="chasemanhattanbankna[merged]"
replace bankid= 53 if banks=="chemburnagariksahakaribankltd"
replace bankid= 54 if banks=="chinatrustcommercialbank"
replace bankid= 55 if banks=="chohungbank"
replace bankid= 56 if banks=="citibankna"
replace bankid= 57 if banks=="citizencreditcoopbankltd"
replace bankid= 58 if banks=="citycoopbankltd"
replace bankid= 59 if banks=="cityunionbankltd" | banks=="cityunionbanklimited"
replace bankid= 60 if banks=="commerzbankag"
replace bankid= 61 if banks=="cooperativebankofahmedabadltd"
replace bankid= 62 if banks=="cooperativebankofrajkotltd"
replace bankid= 63 if banks=="corporationbank"
replace bankid= 64 if banks=="cosmoscooperativebankltd"
replace bankid= 65 if banks=="creditlyonnais"
replace bankid= 66 if banks=="dbsbankltd" | banks=="thedevelopmentbankofsingaporeltd"
replace bankid= 67 if banks=="deccanmerchantscoopbankltd"
replace bankid= 68 if banks=="delhifinancialcorpn"
replace bankid= 69 if banks=="denabank"
replace bankid= 70 if banks=="deutschebankag" | banks=="deutschebank(asia)"
replace bankid= 71 if banks=="developmentcreditbankltd"
replace bankid= 72 if banks=="dhanalakshmibankltd"
replace bankid= 73 if banks=="dombivlinagarisahakaribankltd"
replace bankid= 74 if banks=="dresdnerbankag"
replace bankid= 75 if banks=="excellentcooperativebankltd"
replace bankid= 76 if banks=="exportcreditguaranteecorpnofindialtd"
replace bankid= 77 if banks=="exportimportbankofindia"
replace bankid= 78 if banks=="federalbankltd"
replace bankid= 79 if banks=="ganeshbankofkurundwadltd[merged]" | banks=="ganeshbankofkurundwadltd"
replace bankid= 80 if banks=="globaltrustbankltd[merged]" | banks=="globaltrustbanklimited"
replace bankid= 81 if banks=="greaterbombaycoopbankltd"
replace bankid= 82 if banks=="gujaratindustrialcoopbankltd"
replace bankid= 83 if banks=="gujaratindustrialinvestmentcorpnltd"
replace bankid= 84 if banks=="gujaratstatecoopbankltd"
replace bankid= 85 if banks=="gujaratstatefinancialcorpn"
replace bankid= 86 if banks=="gujeratsafedepositcoltd"
replace bankid= 87 if banks=="haryanafinancialcorpn"
replace bankid= 88 if banks=="haryanastateindldevpcorpnltd"
replace bankid= 89 if banks=="hdfcbankltd"
replace bankid= 90 if banks=="himachalpradeshfinancialcorpn"
replace bankid= 91 if banks=="hindusthanmercantilebankltd"
replace bankid= 92 if banks=="hongkong&shanghaibankingcorpnltd" | banks=="hongkongandshanghaibankingcorpnltd"
replace bankid= 93 if banks=="hooseinicooperativecreditsocyltd"
replace bankid= 94 if banks=="housing&urbandevelopmentcorpnltd"
replace bankid= 95 if banks=="hyquestcapitalservicesltd"
replace bankid= 96 if banks=="icicibankltd" | banks=="icicibanklimited"
replace bankid= 97 if banks=="iciciltd[merged]" 
replace bankid= 98 if banks=="iciciprudentialassetmgmtcoltd"
replace bankid= 99 if banks=="idbibankltd" | banks=="idbdbankltd" | banks=="idbibanklimited" | banks=="idbibankltd[merged]"
replace bankid=101 if banks=="idbihomefinanceltd"
replace bankid=102 if banks=="ifciltd"
replace bankid=103 if banks=="ifciventurecapitalfundsltd"
replace bankid=104 if banks=="indianbank"
replace bankid=105 if banks=="indianoverseasbank"
replace bankid=106 if banks=="indianrailwayfinancecorpnltd"
replace bankid=107 if banks=="indianrenewableenergydevpagencyltd"
replace bankid=108 if banks=="indusindbankltd"
replace bankid=109 if banks=="industrialinvestmentbankofindialtd"
replace bankid=110 if banks=="industrialpromotion&investmentcorpnoforissaltd"
replace bankid=111 if banks=="infrastructuredevelopmentfinancecoltd"
replace bankid=112 if banks=="infrastructureleasing&financialservicesltd"
replace bankid=113 if banks=="ingbanknv"
replace bankid=114 if banks=="ingvysyabankltd"
replace bankid=115 if banks=="jainsahakaribankltd"
replace bankid=116 if banks=="jammu&kashmirbankltd"
replace bankid=117 if banks=="janakalyansahakaribankltd"
replace bankid=118 if banks=="janasevasahakaribank(borivli)ltd"
replace bankid=119 if banks=="janatasahakaribankltd"
replace bankid=120 if banks=="jpmorganchasebank,nationalassociation" | banks=="jpmorganchasebank"
replace bankid=121 if banks=="kalupurcommercialcoopbankltd"
replace bankid=122 if banks=="kapolcoopbankltd"
replace bankid=123 if banks=="karadurbancoopbankltd"
replace bankid=124 if banks=="karnatakabankltd"
replace bankid=125 if banks=="karnatakastatefinancialcorpn"
replace bankid=126 if banks=="karnatakastateindlinvst&devpcorpnltd"
replace bankid=127 if banks=="karurvysyabankltd"
replace bankid=128 if banks=="kbcbanknv"
replace bankid=129 if banks=="keralafinancialcorporation"
replace bankid=130 if banks=="keralastateindldevpcorpnltd"
replace bankid=131 if banks=="keralaurbandevelopmentfinancecorpnltd"
replace bankid=132 if banks=="kokanmercantilecoopbankltd"
replace bankid=133 if banks=="kotakmahindrabankltd"
replace bankid=134 if banks=="krishnabhimasamruddhilocalareabankltd"
replace bankid=135 if banks=="krungthaibankpubliccoltd" | banks=="krungthaibankpubliccompanylimited"
replace bankid=136 if banks=="kunbisahakaribankltd"
replace bankid=137 if banks=="kurlanagariksahakaribankltd"
replace bankid=138 if banks=="lakshmivilasbankltd"
replace bankid=139 if banks=="lordkrishnabankltd[merged]" | banks=="lordkrishnabankltd"
replace bankid=140 if banks=="madhyapradeshfinancialcorpn"
replace bankid=141 if banks=="madhyapradeshrajyasahakaribankmaryadit"
replace bankid=142 if banks=="mahakaushalkshetriyagraminbank"
replace bankid=143 if banks=="mahanagarcoopbankltd"
replace bankid=144 if banks=="maharashtrastatefinancialcorpn"
replace bankid=145 if banks=="maladsahakaribankltd"
replace bankid=146 if banks=="mandvicooperativebankltd[merged]"
replace bankid=147 if banks=="mangalcoopbankltd"
replace bankid=148 if banks=="mapusaurbancoopbankofgoaltd"
replace bankid=149 if banks=="marathamandircoopbankltd[merged]"
replace bankid=150 if banks=="marathasahakaribankltd"
replace bankid=151 if banks=="mashreqbankpsc"
replace bankid=152 if banks=="memoncoopbankltd"
replace bankid=153 if banks=="mizuhocorporatebankltd"
replace bankid=154 if banks=="modelcoopbankltd"
replace bankid=155 if banks=="mogaveeracoopbankltd"
replace bankid=156 if banks=="moonhousejewellersltd"
replace bankid=157 if banks=="morganguarantytrustcoofnewyork[merged]" | banks=="morganguarantytrustcoofnewyork"
replace bankid=158 if banks=="mumbaidistrictcentralcoopbankltd"
replace bankid=159 if banks=="nainitalbankltd"
replace bankid=160 if banks=="nationalbankforagriculture&ruraldevelopment"
replace bankid=161 if banks=="nationalcoopbankltd"
replace bankid=162 if banks=="nationalhousingbank"
replace bankid=163 if banks=="nationalsmallindscorpnltd"
replace bankid=164 if banks=="navanirmancoopurbanbankltd"
replace bankid=165 if banks=="nedungadibankltd[merged]" | banks=="nedungadibankltd"
replace bankid=166 if banks=="newindiacoopbankltd"
replace bankid=167 if banks=="nkgsbcoopbankltd"
replace bankid=168 if banks=="northeasterndevpfinancecorpnltd"
replace bankid=169 if banks=="omaninternationalbank" | banks=="omaninternationalbanksaog"
replace bankid=170 if banks=="orientalbankofcommerce" | banks=="orientalbankofcommercelimited"
replace bankid=171 if banks=="orissastatefinancialcorpn"
replace bankid=172 if banks=="overseachinesebankingcorpnltd" | banks=="overseachinesebankingcorporationltd"
replace bankid=173 if banks=="patancooperativebankltd"
replace bankid=174 if banks=="pinakinigrameenabank"
replace bankid=175 if banks=="powerfinancecorpnltd"
replace bankid=176 if banks=="pradeshiyaindustrial&invstcorpnofuttarpradeshltd"
replace bankid=177 if banks=="progressivecoopbankltd"
replace bankid=178 if banks=="punjab&maharashtracoopbankltd"
replace bankid=179 if banks=="punjab&sindbank" | banks=="punjabandsindbank"
replace bankid=180 if banks=="punjabnationalbank"
replace bankid=181 if banks=="raghuvanshicoopbankltd"
replace bankid=182 if banks=="rajasthanstateindldevp&investmentcorpnltd"
replace bankid=183 if banks=="ratnakarbankltd"
replace bankid=184 if banks=="rscooperativebankltd"
replace bankid=185 if banks=="ruralelectrificationcorpnltd"
replace bankid=186 if banks=="sakurabankltd[merged]" |  banks=="thesakurabanklimited"
replace bankid=187 if banks=="samastanagarcoopbankltd"
replace bankid=188 if banks=="sanglibankltd[merged]" | banks=="sanglibankltd"
replace bankid=189 if banks=="santhalparganasgraminbank "
replace bankid=190 if banks=="saraswatcooperativebankltd"
replace bankid=191 if banks=="satarasahakaribankltd"
replace bankid=192 if banks=="sbicommercial&internationalbankltd"
replace bankid=193 if banks=="sbidfhiltd"
replace bankid=194 if banks=="sciciltd[merged]"
replace bankid=195 if banks=="securitiestradingcorpnofindialtd"
replace bankid=196 if banks=="shalinisahakaribankltd"
replace bankid=197 if banks=="shamraovithalcoopbankltd"
replace bankid=198 if banks=="shinhanbank"
replace bankid=199 if banks=="shreejibhatiacoopbankltd"
replace bankid=200 if banks=="shreesuvarnasahakaribankltd"
replace bankid=201 if banks=="shriarihantcoopbankltd"
replace bankid=202 if banks=="siamcommercialbank" | banks=="thesiamcommercialbanklimited"
replace bankid=203 if banks=="sicomltd"
replace bankid=204 if banks=="smallindustriesdevpbankofindia"
replace bankid=205 if banks=="societegenerale"
replace bankid=206 if banks=="solapurdistrictcentralcoopbankltd"
replace bankid=207 if banks=="sonalibank"
replace bankid=208 if banks=="southgujaratlocalareabankltd[merged]"
replace bankid=209 if banks=="southindianbankltd"
replace bankid=210 if banks=="southindiancoopbankltd"
replace bankid=211 if banks=="sreenarayanagurucoopbankltd"
replace bankid=212 if banks=="srinivasaperumalbankltd"
replace bankid=213 if banks=="standardcharteredbank"
replace bankid=214 if banks=="standardcharteredgrindlaysbankltd[merged]" | banks=="standardcharteredgrindlaysbankltd"
replace bankid=215 if banks=="statebankofbikaner&jaipur" | banks=="statebankofbikanerandjaipur"
replace bankid=216 if banks=="statebankofhyderabad"
replace bankid=217 if banks=="statebankofindia"
replace bankid=218 if banks=="statebankofindore"
replace bankid=219 if banks=="statebankofmauritiusltd"
replace bankid=220 if banks=="statebankofmysore"
replace bankid=221 if banks=="statebankofpatiala"
replace bankid=222 if banks=="statebankofsaurashtra"
replace bankid=223 if banks=="statebankoftravancore"
replace bankid=224 if banks=="stateindustriespromotioncorpnoftamilnadultd"
replace bankid=225 if banks=="statetransportcoopbankltd"
replace bankid=226 if banks=="sumitomobankltd[merged]"
replace bankid=227 if banks=="sumitomomitsuibankingcorpn" | banks=="sumitomomitsuibankingcorporation"
replace bankid=228 if banks=="syndicatebank"
replace bankid=229 if banks=="tamilnadmercantilebankltd"
replace bankid=230 if banks=="tamilnaduindustrialdevpcorpnltd"
replace bankid=231 if banks=="tamilnaduindustrialinvestmentcorpnltd"
replace bankid=232 if banks=="tamilnadupowerfinance&infrastructuredevpcorpnltd"
replace bankid=233 if banks=="tamilnadustateapexcoopbankltd"
replace bankid=234 if banks=="thanejanatasahakaribankltd"
replace bankid=235 if banks=="timesbankltd[merged]" | banks=="timesbanklimited"
replace bankid=236 if banks=="torontodominionbank" | banks=="thetorontodominionbank"
replace bankid=237 if banks=="tourismfinancecorpnofindialtd"
replace bankid=238 if banks=="ucobank"
replace bankid=239 if banks=="ufjbankltd"
replace bankid=240 if banks=="unionbankofindia"
replace bankid=241 if banks=="unitedbankofindia"
replace bankid=242 if banks=="unitedwesternbankltd[merged]"
replace bankid=243 if banks=="vaishyasahakaribankltd"
replace bankid=244 if banks=="vasantsahakaribankltd"
replace bankid=245 if banks=="veerashaivacoopbankltd"
replace bankid=246 if banks=="vijayabank"
replace bankid=247 if banks=="vimakamgarcoopbankltd"
replace bankid=248 if banks=="vinayaklocalareabankltd"
replace bankid=249 if banks=="waiurbancoopbankltd"
replace bankid=250 if banks=="westbengalfinancialcorpn"
replace bankid=251 if banks=="westbengalindldevpcorpnltd"
replace bankid=252 if banks=="yesbankltd"
replace bankid=253 if banks=="zoroastriancoopbankltd"
**this one doesn't exist in the previous file but exists here.
replace bankid=254 if banks=="creditagricoleindosuez"
replace bankid=255 if banks=="arabbangladeshbanklimited"
replace bankid=256 if banks=="utibankltd"
replace bankid=257 if banks=="vysyabankltd"
replace bankid=258 if banks=="thecommercialbankofkorealtd"
replace bankid=259 if banks=="prathamabank"
replace bankid=260 if banks=="newbankofindia"
replace bankid=261 if banks=="hanilbank"
replace bankid=262 if banks=="bankofkaradltd"
replace bankid=263 if banks=="bankofcredit&commerceinternational"
replace bankid=264 if banks=="unitedwesternbankltd"
sort bankid state
count

drop if strpos(banks,"gramin")>0 | strpos(banks,"grameen")>0 | strpos(banks,"gramya")>0 | strpos(banks,"rural")>0 | strpos(banks,"grama")>0 | strpos(banks,"dehati")>0 | strpos(banks,"gaon")>0 | strpos(banks,"cooperative")>0 | strpos(banks,"coop")>0 | strpos(banks,"sahakari")>0 | strpos(banks,"khasi")>0
count if bankid==.

count

egen bankstateyeartag=tag(bankid state year)
tab bankstateyeartag

keep if bankstateyeartag==1

egen bankstatetag=tag(bankid state) 
tab bankstatetag
count

drop bankstateyeartag address authoriseddealersscategory businessstatusofbranch branchname centrename natureofbusiness developmentblockcode developmentblockname /*
*/ districtname distictworkingcode centralgovtbusinessindicator parti partii popgroup populationgroupname regioncode regionname /*
*/ stategovtbusinessindicator openingdate branchtaga branchtage bankname

foreach v in b92 all {
bys bankid: egen checka`v'=total(bankstatea`v')
bys bankid: egen checke`v'=total(bankstatee`v')
}

*duplicates drop bankworkingcode statename, force 

duplicates report bankid state year

count

sort bankid bankgroupcode
bys bankid: replace bankgroupcode=bankgroupcode[_n-1] if bankgroupcode==.

move bankid bankgroupcode
move banks bankgroupcode

drop bankworkingcode statename statecode b92 all check* bankgroupname 

/*
collapse (max) banknrab92=banknrab92 banknrbb92=banknrbb92 banknrcb92=banknrcb92 banknrdb92=banknrdb92 banknreb92=banknreb92 banknraall=banknraall banknrball=banknrball banknrcall=banknrcall banknrdall=banknrdall banknreall=banknreall bankgroupcode=bankgroupcode (sum) bankstateab92=bankstateab92 bankstatebb92=bankstatebb92 bankstatecb92=bankstatecb92 /*
*/ bankstatedb92=bankstatedb92 bankstateeb92=bankstateeb92 bankstateaall=bankstateaall bankstateball=bankstateball bankstatecall=bankstatecall bankstatedall=bankstatedall bankstateeall=bankstateeall, by(bankid state)

xtset bankid state
fillin bankid state
xtset bankid state
*/

***EXPOSURE1 IS NUMBER OF BRANCHES OF THIS BANK IN THIS STATE. DOES NOT ACCOUNT FOR SCALE OF OPERATIONS.
***EXPOSURE2 IS THE FRACTION OF BRANCHES OF THIS BANK THAT ARE IN THIS STATE. ACCOUNTS FOR SCALE OF OPERATIONS.

gen exposure_ca1=conbrancha
gen exposure_ca2=conbrancha/conbanknra
gen exposure_ce1=conbranche
gen exposure_ce2=conbranche/conbanknre
gen exposure_cf1=conbranchf
gen exposure_cf2=conbranchf/conbanknrf

foreach v in b92 all {
gen exposurea1`v'=bankstatea`v'
gen exposurea2`v'=bankstatea`v'/banknra`v'
gen exposuree1`v'=bankstatee`v'
gen exposuree2`v'=bankstatee`v'/banknre`v'
gen exposuref1`v'=bankstatef`v'
gen exposuref2`v'=bankstatef`v'/banknrf`v'

replace exposurea1`v'=0 if exposurea1`v'==. 
replace exposuree1`v'=0 if exposuree1`v'==. 
replace exposuref1`v'=0 if exposuref1`v'==. 
replace exposurea2`v'=0 if exposurea2`v'==. 
replace exposuree2`v'=0 if exposuree2`v'==. 
replace exposuref2`v'=0 if exposuref2`v'==. 
replace banknra`v'=0 if banknra`v'==. 
replace banknre`v'=0 if banknre`v'==. 
replace banknrf`v'=0 if banknrf`v'==. 
}

 
foreach v in b92 all {
bys bankid: egen x`v'=max(banknra`v')
replace banknra`v'=x`v' if banknra`v'==0 & x`v'~=0
drop x`v'
bys bankid: egen x`v'=max(banknre`v')
replace banknre`v'=x`v' if banknre`v'==0 & x`v'~=0
drop x`v'
bys bankid: egen x`v'=max(banknrf`v')
replace banknrf`v'=x`v' if banknrf`v'==0 & x`v'~=0
drop x`v'
}

replace bankstateab92=0 if bankstateab92==.
replace bankstateaall=0 if bankstateaall==.
replace bankstateeall=0 if bankstateeall==.
replace bankstateeall=0 if bankstateeall==.
replace bankstatefall=0 if bankstatefall==.
replace bankstatefall=0 if bankstatefall==.

sort bankid state year
save bankstatewiseexposure_step1, replace

/*
***now create interaction indices
keep bankid state bankstateab92 bankstateaall banknrab92 banknraall
reshape wide bankstateab92 bankstateaall, i(bankid) j(state)

foreach i of numlist 1/17 19/33 {
 gen qb92`i'=bankstateab92`i'/banknrab92
 gen qb92m`i'=(banknrab92-bankstateab92`i')/banknrab92
 egen pb92`i'=rprod(qb92`i' qb92m`i')
 gen qall`i'=bankstateaall`i'/banknraall
 gen qallm`i'=(banknraall-bankstateaall`i')/banknraall
 egen pall`i'=rprod(qall`i' qallm`i')
 gen qb92sq`i'=(qb92`i')^2
 gen qallsq`i'=(qall`i')^2
}

gen Ib92=pb921+pb922+pb923+pb924+pb925+pb926+pb927+pb928+pb929+pb9210+pb9211+pb9212+pb9213+pb9214+pb9215+pb9216+pb9217+pb9219+pb9220+pb9221+pb9222+pb9223+pb9224+pb9225+pb9226+pb9227+pb9228+pb9229+pb9230+pb9231+pb9232+pb9233
gen Iall=pall1+pall2+pall3+pall4+pall5+pall6+pall7+pall8+pall9+pall10+pall11+pall12+pall13+pall14+pall15+pall16+pall17+pall19+pall20+pall21+pall22+pall23+pall24+pall25+pall26+pall27+pall28+pall29+pall30+pall31+pall32+pall33
gen Hb92=qb92sq1+qb92sq2+qb92sq3+qb92sq4+qb92sq5+qb92sq6+qb92sq7+qb92sq8+qb92sq9+qb92sq10+qb92sq11+qb92sq12+qb92sq13+qb92sq14+qb92sq15+qb92sq16+qb92sq17+qb92sq19+qb92sq20+qb92sq21+qb92sq22+qb92sq23+qb92sq24+qb92sq25+qb92sq26+qb92sq27+qb92sq28+qb92sq29+qb92sq30+qb92sq31+qb92sq32+qb92sq33
gen Hall=qallsq1+qallsq2+qallsq3+qallsq4+qallsq5+qallsq6+qallsq7+qallsq8+qallsq9+qallsq10+qallsq11+qallsq12+qallsq13+qallsq14+qallsq15+qallsq16+qallsq17+qallsq19+qallsq20+qallsq21+qallsq22+qallsq23+qallsq24+qallsq25+qallsq26+qallsq27+qallsq28+qallsq29+qallsq30+qallsq31+qallsq32+qallsq33

keep bankid Ib92 Iall Hb92 Hall
sort bankid
save banksintindex, replace

merge bankid using bankstatewiseexposure_step1
tab _merge
drop _merge
*/

rename year fyear
count
save bankstatewiseexposure, replace

*********PREPARE & USE EARNINGS & EXPENSES OF SCBs
insheet using "Earnings and Expenses of SCBs.csv", delimiter(";") clear names

gen fyear=substr(fiscalyear,1,4)
destring fyear, replace
replace fyear=fyear+1
gen march=03
gen yyyy=fyear 
gen accountdate=ym(yyyy,march)
format %tm accountdate
keep if fyear<=2003 

replace amountinrsthousand=subinstr(amountinrsthousand,"'","",.)
destring amountinrsthousand, replace
replace balancesheetplacitems=subinstr(balancesheetplacitems,"'","",.)
destring balancesheetplacitems, replace

replace banks=subinstr(banks,"'","",.)
replace banks=lower(banks)
replace banks=subinstr(banks,".","",.)
replace banks=subinstr(banks," ","",.)
replace banks=subinstr(banks,"-","",.)
replace banks=subinstr(banks,",","",.)

gen     bankid=  1 if banks=="abbankltd"                                      
replace bankid=  2 if banks=="abhyudayacoopbankltd"
replace bankid=  3 if banks=="abnamrobanknv"
replace bankid=  4 if banks=="abudhabicommercialbank" | banks=="abudhabicommercialbankltd"
replace bankid=  5 if banks=="agriculturalfinancecorpnltd"
replace bankid=  6 if banks=="ahmedabadmercantilecooperativebankltd"
replace bankid=  7 if banks=="allahabadbank"
replace bankid=  8 if banks=="americanexpressbankltd"
replace bankid=  9 if banks=="americanexpressintlbankingcorpn"
replace bankid= 10 if banks=="andhrabank"
replace bankid= 11 if banks=="andhrapradeshstatefinancialcorpn"
replace bankid= 12 if banks=="antwerpdiamondbanknv"
replace bankid= 13 if banks=="apexcooperativebank"
replace bankid= 14 if banks=="apmaheshcooperativeurbanbankltd"
replace bankid= 15 if banks=="apnacooperativeurbanbankltd"
replace bankid= 16 if banks=="apnasahakaribankltd"
replace bankid= 17 if banks=="assamfinancialcorpn"
replace bankid= 18 if banks=="assamindustrialdevpcorpnltd"
replace bankid= 19 if banks=="axisbankltd"
replace bankid= 20 if banks=="bankinternationalindonesia" | banks=="bankinternasionalindonesia"
replace bankid= 21 if banks=="bankmuscatalahlialomani" | banks=="bankmuscatinternationalsaog" | banks=="bankmuscatsaog"
replace bankid= 23 if banks=="bankofamericanationaltrust&savingsassociation" | banks=="bankofamericantandsa" | | banks=="bankofamericana"
replace bankid= 24 if banks=="bankofbahrain&kuwaitbsc"
replace bankid= 25 if banks=="bankofbaroda"
replace bankid= 26 if banks=="bankofceylon"
replace bankid= 27 if banks=="bankofindia"
replace bankid= 28 if banks=="bankofmaduraltd[merged]" | banks=="bankofmaduraltd"
replace bankid= 29 if banks=="bankofmaharashtra"
replace bankid= 30 if banks=="bankofnovascotia"
replace bankid= 31 if banks=="bankofpunjabltd[merged]" | banks=="bankofpunjablimited"
replace bankid= 32 if banks=="bankofrajasthanltd"
replace bankid= 33 if banks=="bankoftokyomitsubishiufjltd" | banks=="bankoftokyomitsubishiltd" | banks=="bankoftokyoltd"
replace bankid= 34 if banks=="banquenationaledeparis"
replace bankid= 35 if banks=="barclaysbankplc"
replace bankid= 36 if banks=="bareillycorporationbankltd"
replace bankid= 37 if banks=="benaresstatebankltd[merged]" | banks=="benarasstatebankltd"
replace bankid= 38 if banks=="bhandaricooperativebankltd"
replace bankid= 39 if banks=="bharatcoopbank(mumbai)ltd"
replace bankid= 40 if banks=="bharatoverseasbankltd[merged]" | banks=="bharatoverseasbankltd"
replace bankid= 41 if banks=="bharatsahakaribankltd"
replace bankid= 42 if banks=="biharstatecoopbankltd"
replace bankid= 43 if banks=="bnpparibas"
replace bankid= 44 if banks=="bombaymercantilecoopbankltd"
replace bankid= 45 if banks=="britishbankofthemiddleeast" | banks=="britishbankofmiddleeast"
replace bankid= 46 if banks=="calyonbank"
replace bankid= 47 if banks=="canarabank"
replace bankid= 48 if banks=="capitallocalareabankltd"
replace bankid= 49 if banks=="catholicsyrianbankltd"
replace bankid= 50 if banks=="centralbankofindia"
replace bankid= 51 if banks=="centurionbankofpunjabltd" | banks=="centurionbankltd"
replace bankid= 52 if banks=="chasemanhattanbankna[merged]"
replace bankid= 53 if banks=="chemburnagariksahakaribankltd"
replace bankid= 54 if banks=="chinatrustcommercialbank"
replace bankid= 55 if banks=="chohungbank"
replace bankid= 56 if banks=="citibankna"
replace bankid= 57 if banks=="citizencreditcoopbankltd"
replace bankid= 58 if banks=="citycoopbankltd"
replace bankid= 59 if banks=="cityunionbankltd" | banks=="cityunionbanklimited"
replace bankid= 60 if banks=="commerzbankag"
replace bankid= 61 if banks=="cooperativebankofahmedabadltd"
replace bankid= 62 if banks=="cooperativebankofrajkotltd"
replace bankid= 63 if banks=="corporationbank"
replace bankid= 64 if banks=="cosmoscooperativebankltd"
replace bankid= 65 if banks=="creditlyonnais"
replace bankid= 66 if banks=="dbsbankltd" | banks=="thedevelopmentbankofsingaporeltd"
replace bankid= 67 if banks=="deccanmerchantscoopbankltd"
replace bankid= 68 if banks=="delhifinancialcorpn"
replace bankid= 69 if banks=="denabank"
replace bankid= 70 if banks=="deutschebankag" | banks=="deutschebank(asia)"
replace bankid= 71 if banks=="developmentcreditbankltd"
replace bankid= 72 if banks=="dhanalakshmibankltd"
replace bankid= 73 if banks=="dombivlinagarisahakaribankltd"
replace bankid= 74 if banks=="dresdnerbankag"
replace bankid= 75 if banks=="excellentcooperativebankltd"
replace bankid= 76 if banks=="exportcreditguaranteecorpnofindialtd"
replace bankid= 77 if banks=="exportimportbankofindia"
replace bankid= 78 if banks=="federalbankltd"
replace bankid= 79 if banks=="ganeshbankofkurundwadltd[merged]" | banks=="ganeshbankofkurundwadltd"
replace bankid= 80 if banks=="globaltrustbankltd[merged]" | banks=="globaltrustbanklimited"
replace bankid= 81 if banks=="greaterbombaycoopbankltd"
replace bankid= 82 if banks=="gujaratindustrialcoopbankltd"
replace bankid= 83 if banks=="gujaratindustrialinvestmentcorpnltd"
replace bankid= 84 if banks=="gujaratstatecoopbankltd"
replace bankid= 85 if banks=="gujaratstatefinancialcorpn"
replace bankid= 86 if banks=="gujeratsafedepositcoltd"
replace bankid= 87 if banks=="haryanafinancialcorpn"
replace bankid= 88 if banks=="haryanastateindldevpcorpnltd"
replace bankid= 89 if banks=="hdfcbankltd"
replace bankid= 90 if banks=="himachalpradeshfinancialcorpn"
replace bankid= 91 if banks=="hindusthanmercantilebankltd"
replace bankid= 92 if banks=="hongkong&shanghaibankingcorpnltd" | banks=="hongkongandshanghaibankingcorpnltd"
replace bankid= 93 if banks=="hooseinicooperativecreditsocyltd"
replace bankid= 94 if banks=="housing&urbandevelopmentcorpnltd"
replace bankid= 95 if banks=="hyquestcapitalservicesltd"
replace bankid= 96 if banks=="icicibankltd" | banks=="icicibanklimited"
replace bankid= 97 if banks=="iciciltd[merged]" 
replace bankid= 98 if banks=="iciciprudentialassetmgmtcoltd"
replace bankid= 99 if banks=="idbibankltd" | banks=="idbdbankltd" | banks=="idbibanklimited" | banks=="idbibankltd[merged]"
replace bankid=101 if banks=="idbihomefinanceltd"
replace bankid=102 if banks=="ifciltd"
replace bankid=103 if banks=="ifciventurecapitalfundsltd"
replace bankid=104 if banks=="indianbank"
replace bankid=105 if banks=="indianoverseasbank"
replace bankid=106 if banks=="indianrailwayfinancecorpnltd"
replace bankid=107 if banks=="indianrenewableenergydevpagencyltd"
replace bankid=108 if banks=="indusindbankltd"
replace bankid=109 if banks=="industrialinvestmentbankofindialtd"
replace bankid=110 if banks=="industrialpromotion&investmentcorpnoforissaltd"
replace bankid=111 if banks=="infrastructuredevelopmentfinancecoltd"
replace bankid=112 if banks=="infrastructureleasing&financialservicesltd"
replace bankid=113 if banks=="ingbanknv"
replace bankid=114 if banks=="ingvysyabankltd"
replace bankid=115 if banks=="jainsahakaribankltd"
replace bankid=116 if banks=="jammu&kashmirbankltd"
replace bankid=117 if banks=="janakalyansahakaribankltd"
replace bankid=118 if banks=="janasevasahakaribank(borivli)ltd"
replace bankid=119 if banks=="janatasahakaribankltd"
replace bankid=120 if banks=="jpmorganchasebank,nationalassociation" | banks=="jpmorganchasebank"
replace bankid=121 if banks=="kalupurcommercialcoopbankltd"
replace bankid=122 if banks=="kapolcoopbankltd"
replace bankid=123 if banks=="karadurbancoopbankltd"
replace bankid=124 if banks=="karnatakabankltd"
replace bankid=125 if banks=="karnatakastatefinancialcorpn"
replace bankid=126 if banks=="karnatakastateindlinvst&devpcorpnltd"
replace bankid=127 if banks=="karurvysyabankltd"
replace bankid=128 if banks=="kbcbanknv"
replace bankid=129 if banks=="keralafinancialcorporation"
replace bankid=130 if banks=="keralastateindldevpcorpnltd"
replace bankid=131 if banks=="keralaurbandevelopmentfinancecorpnltd"
replace bankid=132 if banks=="kokanmercantilecoopbankltd"
replace bankid=133 if banks=="kotakmahindrabankltd"
replace bankid=134 if banks=="krishnabhimasamruddhilocalareabankltd"
replace bankid=135 if banks=="krungthaibankpubliccoltd" | banks=="krungthaibankpubliccompanylimited"
replace bankid=136 if banks=="kunbisahakaribankltd"
replace bankid=137 if banks=="kurlanagariksahakaribankltd"
replace bankid=138 if banks=="lakshmivilasbankltd"
replace bankid=139 if banks=="lordkrishnabankltd[merged]" | banks=="lordkrishnabankltd"
replace bankid=140 if banks=="madhyapradeshfinancialcorpn"
replace bankid=141 if banks=="madhyapradeshrajyasahakaribankmaryadit"
replace bankid=142 if banks=="mahakaushalkshetriyagraminbank"
replace bankid=143 if banks=="mahanagarcoopbankltd"
replace bankid=144 if banks=="maharashtrastatefinancialcorpn"
replace bankid=145 if banks=="maladsahakaribankltd"
replace bankid=146 if banks=="mandvicooperativebankltd[merged]"
replace bankid=147 if banks=="mangalcoopbankltd"
replace bankid=148 if banks=="mapusaurbancoopbankofgoaltd"
replace bankid=149 if banks=="marathamandircoopbankltd[merged]"
replace bankid=150 if banks=="marathasahakaribankltd"
replace bankid=151 if banks=="mashreqbankpsc"
replace bankid=152 if banks=="memoncoopbankltd"
replace bankid=153 if banks=="mizuhocorporatebankltd"
replace bankid=154 if banks=="modelcoopbankltd"
replace bankid=155 if banks=="mogaveeracoopbankltd"
replace bankid=156 if banks=="moonhousejewellersltd"
replace bankid=157 if banks=="morganguarantytrustcoofnewyork[merged]" | banks=="morganguarantytrustcoofnewyork"
replace bankid=158 if banks=="mumbaidistrictcentralcoopbankltd"
replace bankid=159 if banks=="nainitalbankltd"
replace bankid=160 if banks=="nationalbankforagriculture&ruraldevelopment"
replace bankid=161 if banks=="nationalcoopbankltd"
replace bankid=162 if banks=="nationalhousingbank"
replace bankid=163 if banks=="nationalsmallindscorpnltd"
replace bankid=164 if banks=="navanirmancoopurbanbankltd"
replace bankid=165 if banks=="nedungadibankltd[merged]" | banks=="nedungadibankltd"
replace bankid=166 if banks=="newindiacoopbankltd"
replace bankid=167 if banks=="nkgsbcoopbankltd"
replace bankid=168 if banks=="northeasterndevpfinancecorpnltd"
replace bankid=169 if banks=="omaninternationalbank" | banks=="omaninternationalbanksaog"
replace bankid=170 if banks=="orientalbankofcommerce" | banks=="orientalbankofcommercelimited"
replace bankid=171 if banks=="orissastatefinancialcorpn"
replace bankid=172 if banks=="overseachinesebankingcorpnltd" | banks=="overseachinesebankingcorporationltd"
replace bankid=173 if banks=="patancooperativebankltd"
replace bankid=174 if banks=="pinakinigrameenabank"
replace bankid=175 if banks=="powerfinancecorpnltd"
replace bankid=176 if banks=="pradeshiyaindustrial&invstcorpnofuttarpradeshltd"
replace bankid=177 if banks=="progressivecoopbankltd"
replace bankid=178 if banks=="punjab&maharashtracoopbankltd"
replace bankid=179 if banks=="punjab&sindbank" | banks=="punjabandsindbank"
replace bankid=180 if banks=="punjabnationalbank"
replace bankid=181 if banks=="raghuvanshicoopbankltd"
replace bankid=182 if banks=="rajasthanstateindldevp&investmentcorpnltd"
replace bankid=183 if banks=="ratnakarbankltd"
replace bankid=184 if banks=="rscooperativebankltd"
replace bankid=185 if banks=="ruralelectrificationcorpnltd"
replace bankid=186 if banks=="sakurabankltd[merged]" |  banks=="thesakurabanklimited"
replace bankid=187 if banks=="samastanagarcoopbankltd"
replace bankid=188 if banks=="sanglibankltd[merged]" | banks=="sanglibankltd"
replace bankid=189 if banks=="santhalparganasgraminbank "
replace bankid=190 if banks=="saraswatcooperativebankltd"
replace bankid=191 if banks=="satarasahakaribankltd"
replace bankid=192 if banks=="sbicommercial&internationalbankltd"
replace bankid=193 if banks=="sbidfhiltd"
replace bankid=194 if banks=="sciciltd[merged]"
replace bankid=195 if banks=="securitiestradingcorpnofindialtd"
replace bankid=196 if banks=="shalinisahakaribankltd"
replace bankid=197 if banks=="shamraovithalcoopbankltd"
replace bankid=198 if banks=="shinhanbank"
replace bankid=199 if banks=="shreejibhatiacoopbankltd"
replace bankid=200 if banks=="shreesuvarnasahakaribankltd"
replace bankid=201 if banks=="shriarihantcoopbankltd"
replace bankid=202 if banks=="siamcommercialbank" | banks=="thesiamcommercialbanklimited"
replace bankid=203 if banks=="sicomltd"
replace bankid=204 if banks=="smallindustriesdevpbankofindia"
replace bankid=205 if banks=="societegenerale"
replace bankid=206 if banks=="solapurdistrictcentralcoopbankltd"
replace bankid=207 if banks=="sonalibank"
replace bankid=208 if banks=="southgujaratlocalareabankltd[merged]"
replace bankid=209 if banks=="southindianbankltd"
replace bankid=210 if banks=="southindiancoopbankltd"
replace bankid=211 if banks=="sreenarayanagurucoopbankltd"
replace bankid=212 if banks=="srinivasaperumalbankltd"
replace bankid=213 if banks=="standardcharteredbank"
replace bankid=214 if banks=="standardcharteredgrindlaysbankltd[merged]" | banks=="standardcharteredgrindlaysbankltd"
replace bankid=215 if banks=="statebankofbikaner&jaipur" | banks=="statebankofbikanerandjaipur"
replace bankid=216 if banks=="statebankofhyderabad"
replace bankid=217 if banks=="statebankofindia"
replace bankid=218 if banks=="statebankofindore"
replace bankid=219 if banks=="statebankofmauritiusltd"
replace bankid=220 if banks=="statebankofmysore"
replace bankid=221 if banks=="statebankofpatiala"
replace bankid=222 if banks=="statebankofsaurashtra"
replace bankid=223 if banks=="statebankoftravancore"
replace bankid=224 if banks=="stateindustriespromotioncorpnoftamilnadultd"
replace bankid=225 if banks=="statetransportcoopbankltd"
replace bankid=226 if banks=="sumitomobankltd[merged]"
replace bankid=227 if banks=="sumitomomitsuibankingcorpn" | banks=="sumitomomitsuibankingcorporation"
replace bankid=228 if banks=="syndicatebank"
replace bankid=229 if banks=="tamilnadmercantilebankltd"
replace bankid=230 if banks=="tamilnaduindustrialdevpcorpnltd"
replace bankid=231 if banks=="tamilnaduindustrialinvestmentcorpnltd"
replace bankid=232 if banks=="tamilnadupowerfinance&infrastructuredevpcorpnltd"
replace bankid=233 if banks=="tamilnadustateapexcoopbankltd"
replace bankid=234 if banks=="thanejanatasahakaribankltd"
replace bankid=235 if banks=="timesbankltd[merged]" | banks=="timesbanklimited"
replace bankid=236 if banks=="torontodominionbank" | banks=="thetorontodominionbank"
replace bankid=237 if banks=="tourismfinancecorpnofindialtd"
replace bankid=238 if banks=="ucobank"
replace bankid=239 if banks=="ufjbankltd"
replace bankid=240 if banks=="unionbankofindia"
replace bankid=241 if banks=="unitedbankofindia"
replace bankid=242 if banks=="unitedwesternbankltd[merged]"
replace bankid=243 if banks=="vaishyasahakaribankltd"
replace bankid=244 if banks=="vasantsahakaribankltd"
replace bankid=245 if banks=="veerashaivacoopbankltd"
replace bankid=246 if banks=="vijayabank"
replace bankid=247 if banks=="vimakamgarcoopbankltd"
replace bankid=248 if banks=="vinayaklocalareabankltd"
replace bankid=249 if banks=="waiurbancoopbankltd"
replace bankid=250 if banks=="westbengalfinancialcorpn"
replace bankid=251 if banks=="westbengalindldevpcorpnltd"
replace bankid=252 if banks=="yesbankltd"
replace bankid=253 if banks=="zoroastriancoopbankltd"
**this one doesn't exist in the previous file but exists here.
replace bankid=254 if banks=="creditagricoleindosuez"
replace bankid=255 if banks=="arabbangladeshbanklimited"
replace bankid=256 if banks=="utibankltd"
replace bankid=257 if banks=="vysyabankltd"
replace bankid=258 if banks=="thecommercialbankofkorealtd"
replace bankid=259 if banks=="prathamabank"
replace bankid=260 if banks=="newbankofindia"
replace bankid=261 if banks=="hanilbank"
replace bankid=262 if banks=="bankofkaradltd"
replace bankid=263 if banks=="bankofcredit&commerceinternational"
replace bankid=264 if banks=="unitedwesternbankltd"

count

tab banks if bankid==. & strpos(banks,"gramin")==0 & strpos(banks,"grameen")==0 & strpos(banks,"gramya")==0 & strpos(banks,"rural")==0 & strpos(banks,"grama")==0 & strpos(banks,"dehati")==0 & strpos(banks,"gaon")==0, m
drop if strpos(banks,"gramin")>0 | strpos(banks,"grameen")>0 | strpos(banks,"gramya")>0 | strpos(banks,"rural")>0 | strpos(banks,"grama")>0 | strpos(banks,"dehati")>0 | strpos(banks,"gaon")>0 | strpos(banks,"cooperative")>0 | strpos(banks,"coop")>0 | strpos(banks,"sahakari")>0 | strpos(banks,"khasi")>0

count

count if bankid==.

*gen banksacc=substr(banks,1,10)

gen item="income" if balancesheetplacitems=="(C) TOTAL INCOME(+)"
replace item="intearn" if balancesheetplacitems=="(C.1) Interest Earned"
replace item="otherincome" if balancesheetplacitems=="(C.2) Other Income"
replace item="expenses" if balancesheetplacitems=="(D) TOTAL EXPENSES(-)"
replace item="intexpens" if balancesheetplacitems=="(D.1) Interest Expended"
replace item="opexpens" if balancesheetplacitems=="(D.2) Operating Expenses"
replace item="profits" if balancesheetplacitems=="(E) NET PROFIT"
replace item="provisions" if balancesheetplacitems=="(F) Provisions and contingencies(-)"

drop balancesheetplacitems prompts_time2
*duplicates brow banks fyear item
destring amountinrsthousand, replace force
reshape wide amountinrsthousand, i(banks fyear) j(item) string
*reshape long amountinrsthousand, i(banks fyear) j(item) string

sort bankid fyear
*sort banksacc fyear

drop if bankid==.
merge bankid fyear using prowessaccounting
tab _merge
 
sort bankid fyear
*sort banksacc fyear
rename _merge mergeA
sort bankid

renpfix amountinrsthousand
label var income "rbi (c) total income(+)"
label var intearn "rbi (c.1) interest earned"
label var otherincome "rbi (c.2) other income"
label var expenses "rbi (d) total expenses"
label var intexpens "rbi (d.1) interest expended"
label var opexpens "rbi (d.2) operating expenses"
label var profits "rbi (e) net profit"
label var provisions "rbi (f) provisions & contingencies(-)"

drop march yyyy companyname banks year ymfinance_year months banksacc dateold mergeA

/*
old command
reshape wide expenses income intearn intexpens opexpens otherincome profits provisions fiscalyear cf_interest_recd expcompemployeedec1 expcompemployeedec2 inc_revenue_total inc_sales inc_fin_services inc_exp_recovered exp_total exp_salaries_and_wages exp_staff_training exp_prov_dd_bad_advance exp_total_provisions exp_write_offs exp_bad_debts_write_off exp_bad_debts_woff pat deposits_commercial_banks bank_borr_rbi bank_borr_others tot_net_fixed_asst total_assets loan_advance_nbfcs term_loan_advances short_term_loan_advances advance_others loan_and_advance loan_co_deptl_undertaking securtd_n_oth_loans securities_asst_loans cap_adequacy_ratio movement_gross_npa opening_gross_npa prov_for_npa pbdita pbdpta accountdate, i(bankid) j(fyear)
*/

***MERGE WITH BANK-STATE-YEAR DATA ON EXPOSURE
merge 1:m bankid fyear using bankstatewiseexposure
tab _merge
keep if _merge==3
drop _merge

duplicates report bankid state fyear

gen borrcluster=.
*West Bengal                                                                                                     
replace borrcluster=1 if state==15 | state==25                                                                   
*Delhi                                                                                                           
replace borrcluster=2 if state==2                                                                                
*Rajasthan, HPr, Har & Pun & Cha                                                                                      
replace borrcluster=3 if state==12 | state==5 | state==4 | state==17 | state==21                                         
*Karnataka, APr                                                                                                  
replace borrcluster=4 if state==8 | state==1                                                                     
*Gujarat                                                                                                         
replace borrcluster=5 if state==3 | state==23 | state==22                                                        
*TNa, Ker, Pon                                                                                                   
replace borrcluster=6 if state==13 | state==16 | state==11                                                       
*Assam, Meg, Man, Miz, Tri, ArPr, Nag                                                                                            
replace borrcluster=7 if state==19 | state==26 | state==27 | state==28 | state==29 | state==30 | state==31                             
*Bihar/Jha, Orr                                                                                                      
replace borrcluster=8 if state==7 | state==24                                                                               
*MPr, Chh, UPr, Utt                                                                                              
replace borrcluster=9 if state==9 | state==14                                                                    
*Mah & Goa                                                                                                            
replace borrcluster=10 if state==10 | state==20                                                                            
*Lak                                                                                                             
replace borrcluster=11 if state==32                                                                              
*Sik                                                                                                             
replace borrcluster=12 if state==33                                                                              

tab borrcluster, m
tab state if borrcluster==.
**only J&K has no borrcluster, b/c DRT law does not apply there.

gen bdrtdts=mdy(4,27,1994) if borrcluster==1                                                                     
replace bdrtdts=mdy(7,5,1994) if borrcluster==2
replace bdrtdts=mdy(8,30,1994) if borrcluster==3
replace bdrtdts=mdy(11,30,1994) if borrcluster==4
replace bdrtdts=mdy(12,21,1994) if borrcluster==5
replace bdrtdts=mdy(11,4,1996) if borrcluster==6
replace bdrtdts=mdy(1,7,1997) if borrcluster==7
replace bdrtdts=mdy(1,24,1997) if borrcluster==8
replace bdrtdts=mdy(4,7,1998) if borrcluster==9
replace bdrtdts=mdy(7,16,1999) if borrcluster==10
replace bdrtdts=mdy(12,5,1997) if borrcluster==11| borrcluster==12
gen drtdate=mofd(bdrtdts)
format %tm drtdate

move state expenses
duplicates report bankid state fyear

/*
reshape long expenses income intearn intexpens opexpens otherincome profits provisions fiscalyear accountdate cf_interest_recd expcompemployeedec1 expcompemployeedec2 /*
*/ inc_revenue_total inc_sales inc_fin_services inc_exp_recovered exp_total exp_salaries_and_wages exp_staff_training exp_prov_dd_bad_advance exp_total_provisions /*
*/ exp_write_offs exp_bad_debts_write_off exp_bad_debts_woff pat deposits_commercial_banks bank_borr_rbi bank_borr_others tot_net_fixed_asst total_assets /*
*/ loan_advance_nbfcs term_loan_advances short_term_loan_advances advance_others loan_and_advance loan_co_deptl_undertaking securtd_n_oth_loans /*
*/ securities_asst_loans cap_adequacy_ratio movement_gross_npa opening_gross_npa prov_for_npa pbdita pbdpta, i(bankid state) j(fyear) 
*/

gen drtown=0 
replace drtown=1 if drtdate<accountdate & accountdate<. & drtdate<.
replace drtown=0 if fyear==1996

gen exposurehca1=drtown*exposure_ca1
gen exposurehca2=drtown*exposure_ca2
gen exposurehce1=drtown*exposure_ce1
gen exposurehce2=drtown*exposure_ce2
gen exposurehcf1=drtown*exposure_cf1
gen exposurehcf2=drtown*exposure_cf2
bys bankid fyear: egen drtexposure_ca1=total(exposurehca1)
bys bankid fyear: egen drtexposure_ca2=total(exposurehca2)
bys bankid fyear: egen drtexposure_ce1=total(exposurehce1)
bys bankid fyear: egen drtexposure_ce2=total(exposurehce2)
bys bankid fyear: egen drtexposure_cf1=total(exposurehcf1)
bys bankid fyear: egen drtexposure_cf2=total(exposurehcf2)

foreach v in b92 all {
gen exposureha1`v'=drtown*exposurea1`v' 
gen exposureha2`v'=drtown*exposurea2`v' 
gen exposurehe1`v'=drtown*exposuree1`v' 
gen exposurehe2`v'=drtown*exposuree2`v' 
gen exposurehf1`v'=drtown*exposuref1`v' 
gen exposurehf2`v'=drtown*exposuref2`v' 
bys bankid fyear: egen drtexposure_a1`v'=total(exposureha1`v')
bys bankid fyear: egen drtexposure_a2`v'=total(exposureha2`v')
bys bankid fyear: egen drtexposure_e1`v'=total(exposurehe1`v')
bys bankid fyear: egen drtexposure_e2`v'=total(exposurehe2`v')
bys bankid fyear: egen drtexposure_f1`v'=total(exposurehf1`v')
bys bankid fyear: egen drtexposure_f2`v'=total(exposurehf2`v')
}

duplicates report bankid fyear
egen tag=tag(bankid fyear)
keep if tag==1
duplicates report bankid fyear
drop bankstatea* exposure_c* exposurea1* exposurea2* exposuree1* exposuree2* exposuref1* exposuref2* exposureha1* exposureha2* exposurehe1* exposurehe2* exposurehf1* exposurehf2* state
*duplicates drop banks fyear, force 

label def bankgroup 1 "SBI & associates" 2 "nationalised banks" 4 "foreign banks" 5 "regional rural banks" 6 "other scheduled comm banks"
label values bankgroupcode bankgroup

gen income92h=income if fyear==1992
bys bankid: egen income92=max(income92h)

gen loans92h=loan_advance_nbfcs if fyear==1992
bys bankid: egen loans92=max(loans92h)

xtset bankid fyear

label var pbdpta "profits PBDPTA"

gen profits_loans=profits/loan_advance_nbfcs
gen profits_brancha=profits/conbanknra
gen profits_branche=profits/conbanknre
gen profits_branchf=profits/conbanknrf
gen profits_loans92=profits/loans92
gen profits_brancha92=profits/banknrab92
gen profits_branche92=profits/banknreb92
gen profits_branchf92=profits/banknrfb92

gen pbdpta_loans=profits/loan_advance_nbfcs
gen pbdpta_brancha=profits/conbanknra
gen pbdpta_branche=profits/conbanknre
gen pbdpta_branchf=profits/conbanknrf
gen pbdpta_loans92=profits/loans92
gen pbdpta_brancha92=profits/banknrab92
gen pbdpta_branche92=profits/banknreb92
gen pbdpta_branchf92=profits/banknrfb92

label var profits_loans "profits/lending (contemp)"
label var profits_brancha "profits/all branches a (contemp)"
label var profits_branche "profits/all branches e (contemp)"
label var profits_branchf "profits/all branches f (contemp)"
label var profits_loans92 "profits/lending (1992)"
label var profits_brancha92 "profits/all branches a (1992)"
label var profits_branche92 "profits/all branches e (1992)"
label var profits_branchf92 "profits/all branches f (1992)"

label var pbdpta_loans "pbdpta/lending (contemp)"
label var pbdpta_brancha "pbdpta/all branches a (contemp)"
label var pbdpta_branche "pbdpta/all branches e (contemp)"
label var pbdpta_branchf "pbdpta/all branches f (contemp)"
label var pbdpta_loans92 "pbdpta/lending (1992)"
label var pbdpta_brancha92 "pbdpta/all branches a (1992)"
label var pbdpta_branche92 "pbdpta/all branches e (1992)"
label var pbdpta_branchf92 "pbdpta/all branches f (1992)"

label var inc_fin_services "income financial services" 
label var exp_prov_dd_bad_advance "expenditures bad advances"
label var exp_write_offs "expenses write offs"
label var exp_bad_debts_write_off "bad debt write offs"
label var pat "profits after taxes" 
label var loan_and_advance "loans and advances"
label var securtd_n_oth_loans "securitized and other loans?"

gen logincome=log(1+inc_fin_services)
gen profitabpro=pat/inc_fin_services 
label var profitabpro "profits after taxes/income fin service"

xi i.fyear, prefix(ydum)
*xi i.bankid, prefix(bid)
compress
/*
xi i.bankid*fyear, prefix(bidt)
compress
xi i.bankid*i.fyear, prefix(bidy)
compress
xi i.bankgroupcode*fyear, prefix(bgpt)
compress
xi i.bankgroupcode*i.fyear, prefix(bgpy)
compress
*/

/*
gen bab92t=banknrab92*fyear
gen beb92t=banknreb92*fyear
gen inc92t=income92*fyear

xi i.fyear*banknrab92, prefix(ab92)
xi i.fyear*banknraall, prefix(aall)
xi i.fyear*banknreb92, prefix(eb92)
xi i.fyear*banknreall, prefix(eall)

xi i.fyear*income92, prefix(incy)

xi i.fyear*Ib92, prefix(Ib92)
xi i.fyear*Iall, prefix(Iall)
xi i.fyear*Hb92, prefix(Hb92)
xi i.fyear*Hall, prefix(Hall)
*/

label var drtexposure_a1b92 "DRT exposure"
label var drtexposure_e1b92 "DRT exposure"
label var drtexposure_f1b92 "DRT exposure"
label var drtexposure_a1all "DRT exposure"
label var drtexposure_e1all "DRT exposure"
label var drtexposure_f1all "DRT exposure"

compress
save bankleveldata.dta, replace
