//This do file generates the regressions for Table XVIII in the article.

clear
cap log close
log using legalsuits.log, replace

use <PUT IN NAME OF DATA SET HERE>, clear
des
summ

*notes finished: Finished == bank can expect recovery for any of these reasons: (a) recovery certificate has been issued, or (b) case has been settled or (c) there has been a consent decree
notes
tab venue
tab decree

//Case ID 13 is an outlier.

**Defining the "dependent variables"
gen timefilesummons=summonsdt-filedt
gen timesummonshear1=subhear1dt-summonsdt
gen timesummonsappev=applevidencedt-summonsdt
gen timesummonsdefev=defevidencedt-summonsdt
gen timefileclose=caseclosedt-filedt

gen timefilehear1=subhear1dt-filedt
gen timefilehear2=subhear2dt-filedt

notes timefilesummons: summonsdt-filedt
notes timesummonshear1: subhear1dt-summonsdt
notes timesummonsappev: applevidencedt-summonsdt
notes timesummonsdefev: defevidencedt-summonsdt
notes timefileclose: caseclosedt-filedt
notes timefilehear1: subhear1dt-filedt
notes timefilehear2: subhear2dt-filedt

gen filevenue=1 if filedin=="bomhc"
replace filevenue=2 if filedin=="mdrt1"
replace filevenue=2 if filedin=="mdrt2"
replace filevenue=2 if filedin=="mdrt3"
replace filevenue=2 if filedin=="punedrt"

label define filevenue 1 "hc" 2 "drt"
label var filevenue filevenue
label list filevenue
summ filevenue if caseid~=13
tab filevenue if caseid~=13


**Time to first hearing as a function of where the summons were issued from
gen summonsvenue=1 if filevenue==1 & transfdt>summonsdt & caseid~=13
replace summonsvenue=2 if filevenue==1 & transfdt<summonsdt & caseid~=13
replace summonsvenue=2 if filevenue==2 & caseid~=13

*generate first effective hearing b/c different in DRTs and HCs b/c of Letters Patent
gen timeeffectivehear1=timefilehear1 if summonsvenue==2 & caseid~=13
replace timeeffectivehear1=timefilehear2 if summonsvenue==1 & caseid~=13

**Time to arguments starting as a function of where the first hearing took place
gen hear1venue=1 if summonsvenue==1 & transfdt>subhear1dt & caseid~=13
replace hear1venue=2 if summonsvenue==1 & transfdt<subhear1dt & caseid~=13
replace hear1venue=2 if summonsvenue==2 & caseid~=13

**Fraction claim awarded
gen rsclaimsz=claimsz/1000000
gen reccertsz=real(reccertsize)
gen fracclaim=reccertsz/claimsz

**Probability that case goes in bank's favor
gen bankfavor=(decree==2|decree==3)
gen moved=(decree==2|decree==3|decree==4)
gen prbankfavor=bankfavor/moved

***Checking if the case processing times changed as a result of DRTs *differentially* for small and large claim sizes

gen drtfile=(filevenue==2)
gen drtsummons=(summonsvenue==2)
gen claimdrtfile=rsclaimsz*drtfile
gen claimdrtsummons=rsclaimsz*drtsummons
label var drtfile "DRT"
label var drtsummons "DRT"
label var rsclaimsz "Claim size"
label var claimdrtfile "DRT x Claim size"
label var claimdrtsummons "DRT x Claim size"

reg timefilesummons drtfile rsclaimsz claimdrtfile if caseid~=13, robust
estimates store Timetosummons

reg timeeffectivehear1 drtfile rsclaimsz claimdrtfile if caseid~=13, robust
estimates store Timeeffectivehear1

reg timesummonsappev drtfile rsclaimsz claimdrtfile if caseid~=13, robust
estimates store Timesummonsappev

reg timefileclose drtfile rsclaimsz claimdrtfile if caseid~=13, robust
estimates store Timefileclose

reg timetointrelief drtfile rsclaimsz claimdrtfile if caseid~=13, robust
estimates store Timetointrelief

reg intreliefgranted drtfile rsclaimsz claimdrtfile if caseid~=13, robust
estimates store Intreliefgranted

reg prbankfavor drtfile rsclaimsz claimdrtfile if caseid~=13, robust
estimates store Prbankfavor
