/*

This file generates the majority of results presented in the paper: all results using the Prowess database. 
It makes use of the file called " dataprowess.dta" which has been generated using the do file gendatadirectfromprowess.do
*/

clear
set more off



cd "E:\papers\sujataanddilip\ecmafinal"


use dataprowess.dta


 

 
*****************
*****************SUMMARY STATISTICS
*****************
label var drtown "DRT"
 
 
eststo:  quietly estpost summarize  Lassets  borrowing  /*
    */ ltermbo assets pbdt intpay  salaries t if  t>=firstregressionsyear &t<=lastregressionsyear & tag==1 

eststo:  quietly estpost summarize  Lassets    borrowing  /*
    */ ltermbo assets pbdt intpay  salaries t if  t>=1994 &t<=1999 & tag==1 
eststo:  quietly estpost summarize  Lassets    borrowing  /*
    */ ltermbo assets pbdt intpay  salaries t  if  t==1990 & tag==1 




esttab using summary.csv,addnote("  Standard deviation in brackets. " )   nonumbers  label style(tex) fragment  replace  nostar cells((  mean(fmt(a2)) min(fmt(a2))  & max(fmt(a1 a1 a1 0 a1 ))  )   sd(fmt(a2) par(\begin{footnotesize}(  \end{footnotesize})) )      ) /*
   */mgroups("All years" "Years with DRT changes" "1990", pattern(1    1   1   ) span prefix(\multicolumn{@span}{c}{)suffix(}))   /*
   */ incelldelimiter(/)  unstack  

estimates clear

sort quart
by quart: eststo:  quietly estpost summarize Lassets   borrowing  /*
    */ ltermbo assets pbdt intpay  salaries t if  t>=firstregressionsyear &t<=lastregressionsyear  & tag==1 
 



esttab using summary2.csv,addnote("  Standard deviation in brackets. " )   nonumbers  label style(tex) fragment  replace  nostar cells((  mean(fmt(a2)) min(fmt(a2))  & max(fmt(a1 a1 a1 0 a1 ))  )   sd(fmt(a2) par(\begin{footnotesize}(  \end{footnotesize})) )      ) /*
   */mgroups("Quart 1" "Quart 2" "Quart 3" "Quart 4", pattern(1    1   1  1 ) span prefix(\multicolumn{@span}{c}{)suffix(}))   /*
   */ incelldelimiter(/)  unstack  

estimates clear
 
*****************
*****************END SUMMARY STATISTICS
*****************




****************************
****************************HERE COME THE PRETREND REGRESSIONS
****************************



estimates clear
drop early
gen early=1 if borrcluster<=5
replace early=0 if borrcluster>5 & borrcluster<.

gen nodrtyears=drtyear-1993
drop drtyears
gen drtyears=2003-nodrtyears-1994
sort early
by early: sum drtyears
 
gen earlytrend=early*t 
gen earlyassettrend=early*t*Lassets 
gen tdrtyear=drtyears*t 
 gen tdrtyearass= drtyears*t*Lassets 

xi3 i.early*t  i.t

foreach y of varlist borrowing   /*
 */ assets   pbdt  intpay  {
set more off
 
xi3: xtreg `y' earlytrend i.t  if  t>=1988 &  t<=1993 , fe cluster(state)
estadd scalar numberofgroups = e(N_g) 

estimates store trend2`y'

 

xi3: xtreg `y'   earlytrend  earlyassettrend i.t Lassets*i.t if t>=1988 & t<=1993 , fe cluster(state)
estadd scalar numberofgroups = e(N_g) 
 
estimates store trend1`y'


 

xi3: xtreg `y' tdrtyear i.t   if t>=1988 & t<=1993, fe cluster(state)
estadd scalar numberofgroups = e(N_g) 

estimates store trend4`y'

 
xi3: xtreg `y' tdrtyear tdrtyearass i.t Lassets*i.t if t>=1988 & t<=1993 , fe cluster(state)
estadd scalar numberofgroups = e(N_g) 

estimates store trend3`y'
 

}

gen _Iea1Xt=.
gen _Iea1XtXLa =. 
label var _Iea1Xt "early*t"
label var t "t"
label var  borrowings  "borr."

*label var  _Iea1XtXLa  " early*t*Tang.ass. "

*label var  _IdrXLa "drtyears*Tang.ass."
*label var  _ItXLa "t*Tang.ass."
*label var  _IdrXtXLa "drtyears*t*Tang.ass."


esttab   trend2borrowings trend1borrowings trend4borrowings trend3borrowings trend2assets trend1assets trend4assets trend3assets  using pretrend1.csv,  /*
   */  stats(  numberofgroups r2 N , labels( "number of firms")) replace label star(* 0.10 ** 0.05 *** 0.01)  /*
   */ title(Pre-trends.\label{pretrends1}) /*
   */ addnote("Standard errors are  at the state-level. All regressions use borrower fixed effects.")/*
   */  keep(  earlytrend earlyassettrend tdrtyear tdrtyearass        ) indicate( "YearDummy =   _It_1*" "YDum*Size = _ILaX*"   ) 




esttab trend2pbdt  trend1pbdt  trend4pbdt  trend3pbdt  trend2intpay trend1intpay trend4intpay trend3intpay  using pretrend2.csv,  /*
   */  stats(  numberofgroups r2 N, labels( "number of firms")) replace label star(* 0.10 ** 0.05 *** 0.01)  /*
   */ title(Pre-trends.\label{pretrends2}) /*
   */ addnote("Standard errors are  at the state-level. All regressions use borrower fixed effects.")/*
   */  keep(  earlytrend earlyassettrend tdrtyear tdrtyearass  ) indicate( "YearDummy =   _It_1*" "YDum*Size = _ILaX*") 

 
drop if t<=1989




******************
*****************BASELINE RESULTS
*****************



**************************************************************FIRST BASELINE SPECIFICATION: YEAR DUMMY AND YEAR DUMMY INTERACTED WITH SIZE
 
 

estimates clear
 foreach y of varlist borrowing  /*
 */ assets pbdt  {

 xtreg `y'   drtown    t1990- t2004  if  t>=firstregressionsyear &t<=lastregressionsyear , fe cluster(state)
estadd scalar numberofgroups = e(N_g) 
eststo
  xtreg `y'   drtown t1990- t2004  statetrend1- statetrend33   if  t>=firstregressionsyear &t<=lastregressionsyear , fe cluster(state)
estadd scalar numberofgroups = e(N_g) 
eststo


 xtreg `y'   drtown drtsize        t1990- t2004    t1990size- t2004size     if   t>=firstregressionsyear &t<=lastregressionsyear  , fe cluster(state)
estadd scalar numberofgroups = e(N_g) 
estadd scalar unaffect  = - _b[drtown]/_b[ drtsize]
eststo

 xtreg `y'   drtown drtsize        t1990- t2004    t1990size- t2004size    statetrend1- statetrend33   statetrendsize1- statetrendsize33   if   t>=firstregressionsyear &t<=lastregressionsyear  , fe cluster(state)
estadd scalar numberofgroups = e(N_g) 
estadd scalar unaffect  = - _b[drtown]/_b[ drtsize]

eststo

}






esttab  * using baseline.csv , star(* 0.10 ** 0.05 *** 0.01)  label /*
   */ title(The effect of DRT on borrowing, assets, and profits: Main specification. \label{t2a}) /*
   */ addnote("Standard errors are clustered at the state- level.") replace  /*
   */  keep(drtown drtsize     ) stats(numberofgroups unaffect r2 N , labels("number of firms" " $\tilde W$ ") ) /*
   */    indicate("YearDummy =  t1995 t1996 "    "YDumm*Size=  t1995size  t1996size "  "Statetrend = statetrend1 statetrend7  statetrend8  " "  Statetrendsize= statetrendsize*  ")   


 




 

********************
********************END BASELINE REGRESSIONS
********************











****************************************This produces table "Robustness wrt Size-Specific Time Trends, State level lending, and industry shocks"
estimates clear

set more off
forvalues i = 10(10)10 {
  xtile sizeclass=Lassets if t==1990, nq(`i')
     bys bid: egen x=max(sizeclass)
     drop sizeclass
     rename x class
*keep if t>=1990 &t<=2002 

foreach y of varlist borrowing   /*
 */ assets   pbdt  {
 xtreg `y'  drtown drtsize      t1990-t2004    t1990size- t2004size     if  t>=firstregressionsyear &t<=lastregressionsyear  , fe cluster(state)
estadd scalar numberofgroups = e(N_g) 
estadd scalar unaffect  = - _b[drtown]/_b[ drtsize]


estimates store FE`y'2



xi: xtreg `y'  drtown drtsize  i.class*i.t if  t>=firstregressionsyear &t<=lastregressionsyear , fe cluster(state)

estadd scalar numberofclasses = `i'
estadd scalar numberofgroups = e(N_g) 
estadd scalar unaffect  = - _b[drtown]/_b[ drtsize]


estimates store FEtime`y'1

drop _*
xi: xtreg `y'  drtown drtsize  i.class*i.t  t1990size- t2004size  if t>=firstregressionsyear &t<=lastregressionsyear , fe cluster(state)
estadd scalar numberofclasses = `i'
estadd scalar numberofgroups = e(N_g) 

estadd scalar unaffect  = - _b[drtown]/_b[ drtsize]

estimates store FEtime`y'2

}


*drop nic* 

run "xi31.txt", nostop

*run "C:\Documents and Settings\UL.1798\My Documents\Sujatanddilip\SujataRegWorldbank\prowess\results\xi31.txt", nostop
foreach y of varlist borrowing   /*
 */ assets   pbdt  {
forvalues i = 10(10)10 {


 xtreg `y'  drtown drtsize   _It_1991 -  _ILaXcl10Xt2002 if  t>=firstregressionsyear &t<=lastregressionsyear , fe cluster(state)
estadd scalar numberofclasses = `i'
estadd scalar numberofgroups = e(N_g) 

estadd scalar unaffect  = - _b[drtown]/_b[ drtsize]

estimates store FEtime`y'3
  }

}
drop class

 
* foreach cluster of varlist state {


foreach y of varlist borrowing   /*
 */ assets   pbdt  {
set more off
xi: xtreg `y' drtown drtsize        t1990- t2004    t1990size- t2004size    itlog1st-itlog4st itlog6st-itlog9st itlog11st - itlog14st  if  t>=firstregressionsyear &t<=lastregressionsyear , fe cluster(state)
estadd scalar numberofgroups = e(N_g) 
estadd scalar unaffect  = - _b[drtown]/_b[ drtsize]


estimates store `y'statelevel2

 xi: xtreg `y' drtown drtsize      i.t*i.nic2digit  t1990- t2004    t1990size- t2004size  if  t>=firstregressionsyear &t<=lastregressionsyear  , fe cluster(state)
estadd scalar unaffect  = - _b[drtown]/_b[ drtsize]
estadd scalar numberofgroups = e(N_g) 

estimates store `y'ind




}
}
 label var borrowings "borrow."
label var borrowings "borrow."

 label var drtown "DRT"
 
label var Lassets "1990assets"
label var pbdt "profits"
label var intpay "interest"
label var salar "wagebill"




esttab  FEtimeborrowings2 FEtimeborrowings3 borrowingsstatelevel2 borrowingsind   FEtimeassets2 FEtimeassets3 assetsstatelevel2 assetsind  FEtimepbdt2 FEtimepbdt3 pbdtstatelevel2 pbdtind using robustness.csv,  /*
   */  stats(numberofgroups unaffect r2 N , labels("number of firms" " $\tilde W$ ") )  replace label star(* 0.10 ** 0.05 *** 0.01)  /*
   */ title(Robustness wrt Size-Specific Time Trends, state level lending, and industry shocks.\label{t3a}) /*
   */ addnote("Standard errors are clustered at the state- level. All regressions use borrower fixed effects.")/*
   */  keep(drtown drtsize     )  indicate( "YearDummy =  _It_* t1992 t1993 t1994" "YDum*Size = t1992size t1995size t2002size     " "YDum*SizeClass =  _Icl*"  "YDum*SizeCl.*Size = _ILa*"  "State-loglend =  itlog1st  itlog2st  itlog3st"  "Y*NIC2 = _I* "  )  
 


**************************************PIECEWISELINEAR EFFECTS
drop if t<1990
estimates clear
foreach y of varlist borrowing   /*
 */ assets   pbdt  {



 
local i = 4

 

set more off
  xtile sizeclass=Lassets if t==1990, nq(4)
     bys bid: egen x=max(sizeclass)
     drop sizeclass
     rename x class
 
run xi35.txt, nostop

 


xtreg `y' drtown   _Idr*  _It_*  _Ic*  _Is*  if t>=firstregressionsyear &t<=lastregressionsyear , fe cluster(state)

estadd scalar class1  = _b[drtown]
 test drtown= 0
estadd scalar F_class1 = r(F) 


estadd scalar p_class1 = r(p)

forvalues j = 2(1)`i'{
estadd scalar class`j'  = _b[drtown] + _b[   _IdrXcl`j']

test _b[drtown] + _b[ _IdrXcl`j'] = 0

estadd scalar F_class`j' = r(F) 

estadd scalar p_class`j' = r(p)

}

estadd scalar numberofgroups = e(N_g) 
estimates store np`k'`y'2


drop class
 

}

forvalues j = 1(1)4{
local verynew="class`j' p_class`j' "
local new = "`testclass'"
local testclass =   "`new' `verynew'"
}

 label var drtown "DRT"
 
 
label var _IdrXcl2 "DRT*quart=2"
label var _IdrXcl`j'3 "DRT*quart=3"
label var _IdrXcl`j'4 "DRT*quart=4"

 


esttab  *  using t5a.csv,  replace  /* 
*/   label star(* 0.10 ** 0.05 *** 0.01)title(Average effects by quartile.\label{t5a})/*
 */ addnote("Standard errors are clustered at the state- level. All regressions use borrower fixed effects.")/*   
*/ stats(`testclass' numberofgroups  r2 N , layout(@ `"(@)"' @ `"(@)"' @ `"(@)"' @ `"(@)"' "number of firms") label("DRT effect on quart 1." "P-valuequart 1 effect." "DRT effect on quart 2." "P-value quart 2 effect." "DRT effect on quart 3." "P-value quart 3 effect." "DRT effect on quart 4." "P-value quart 4 effect."))  /* 
*/ keep(drtown   _Idr*  )   indicate("YearDummy = _It_19*"  "YearDum*SizeClass =  _Ic*"   "Statetrend*SizeClass = _Is*   ")  
 

local verynew=""
local new =""
local testclass = ""
 




**************************
**************************THESE ARE THE RESULTS FOR INTEREST RATE AND WAGES
**************************
 

  

set more off

 
foreach y of varlist  intpay salar  {

 estimates clear

 
  xtreg `y'   drtown t1990- t2004  statetrend1- statetrend33   if  t>=firstregressionsyear &t<=lastregressionsyear , fe cluster(state)
estadd scalar numberofgroups = e(N_g) 
eststo

 
 xtreg `y'   drtown drtsize        t1990- t2004    t1990size- t2004size    statetrend1- statetrend33   statetrendsize1- statetrendsize33   if   t>=firstregressionsyear &t<=lastregressionsyear  , fe cluster(state)
estadd scalar numberofgroups = e(N_g) 
estadd scalar unaffect  = - _b[drtown]/_b[ drtsize]

eststo







 
*foreach cluster of varlist state {

drop if t<1990
 

 




foreach k of numlist    4   {
local i = `k'

 

set more off
  xtile sizeclass=Lassets if t==1990, nq(`i')
     bys bid: egen x=max(sizeclass)
     drop sizeclass
     rename x class
 
run xi35.txt, nostop


}

*estadd scalar numberofgroups = e(N_g) 


*estimates store np`k'`y'1 


display "`y'" "state and state-size trend"


xtreg `y' drtown   _Idr*  _It_*  _Ic*  _Is*  if t>=firstregressionsyear &t<=lastregressionsyear , fe cluster(state)

estadd scalar class1  = _b[drtown]
 test drtown= 0
estadd scalar F_class1 = r(F) 


estadd scalar p_class1 = r(p)

forvalues j = 2(1)`i'{
estadd scalar class`j'  = _b[drtown] + _b[   _IdrXcl`j']

test _b[drtown] + _b[ _IdrXcl`j'] = 0

estadd scalar F_class`j' = r(F) 

estadd scalar p_class`j' = r(p)

}

estadd scalar numberofgroups = e(N_g) 
estimates store np`k'`y'2



forvalues j = 1(1)4{
local verynew="class`j' p_class`j' "
local new = "`testclass'"
local testclass =   "`new' `verynew'"
}

 label var drtown "DRT"
 
 
label var _IdrXcl2 "DRT*quart=2"
label var _IdrXcl`j'3 "DRT*quart=3"
label var _IdrXcl`j'4 "DRT*quart=4"



label var intpay "intrate"

esttab * using `y'.csv, replace    label star(* 0.10 ** 0.05 *** 0.01)/*
   */ title(Effects on `y'.\label{`y'}) /*
 */ addnote("Standard errors are clustered at the state- level. All regressions use borrower fixed effects.")/*   
*/ stats(`testclass' numberofgroups unaffect  r2 N , layout(@ `"(@)"' @ `"(@)"' @ `"(@)"' @ `"(@)"' ) label("DRT effect on class 1." "P-value quart 1 effect." "DRT effect on quart 2." "P-value quart 2 effect." "DRT effect on quart 3." "P-value quart 3 effect." "DRT effect on quart 4." "P-value quart 4 effect." "number of firms" " $\tilde W$ "))  /* 
*/ keep(drtown drtsize  _Idr* )   indicate("YearDummy = _It_*  t1995 t1996 " "YearDum*SizeClass =   _Ic*"   "Statetrend*SizeClass = _Is*   " "YDumm*Size=  t1995size  t1996size "  "Statetrend = statetrend1 statetrend7  statetrend8  " "  Statetrendsize= statetrendsize*  ")   
drop class
local verynew=""
local new =""
local testclass = ""
}


 
***************************
***************************END OF SALARY AND INTRATE REGRESSIONS
***************************
 


********************************Generating the table: "Measuring the dependent variables in log"

gen logplama=log(plantmachinery)
replace logplama=log(1) if plantmachinery<=1

gen logbor=log(borrowing)
replace logbor=log(1) if borrowings<=1 

gen  logpro=log(pbdt)



drop if t<1990
estimates clear
foreach y of varlist logbor logplama /*
 */ logpro{



 
local i = 4

 

set more off
  xtile sizeclass=Lassets if t==1990, nq(4)
     bys bid: egen x=max(sizeclass)
     drop sizeclass
     rename x class
 
run xi35.txt, nostop

 


xtreg `y' drtown   _Idr*  _It_*  _Ic*  _Is*  if t>=firstregressionsyear &t<=lastregressionsyear , fe cluster(state)

estadd scalar class1  = _b[drtown]
 test drtown= 0
estadd scalar F_class1 = r(F) 


estadd scalar p_class1 = r(p)

forvalues j = 2(1)`i'{
estadd scalar class`j'  = _b[drtown] + _b[   _IdrXcl`j']

test _b[drtown] + _b[ _IdrXcl`j'] = 0

estadd scalar F_class`j' = r(F) 

estadd scalar p_class`j' = r(p)

}

estadd scalar numberofgroups = e(N_g) 
estimates store np`k'`y'2


drop class
 

}

forvalues j = 1(1)4{
local verynew="class`j' p_class`j' "
local new = "`testclass'"
local testclass =   "`new' `verynew'"
}

 label var drtown "DRT"
 
 
label var _IdrXcl2 "DRT*quart=2"
label var _IdrXcl`j'3 "DRT*quart=3"
label var _IdrXcl`j'4 "DRT*quart=4"

 


esttab  *  using logreg.csv,  replace  /* 
*/   label star(* 0.10 ** 0.05 *** 0.01)title(Measuring the dependent variable in logs.\label{t5a})/*
 */ addnote("Standard errors are clustered at the state- level. All regressions use borrower fixed effects.")/*   
*/ stats(`testclass' numberofgroups  r2 N , layout(@ `"(@)"' @ `"(@)"' @ `"(@)"' @ `"(@)"' "number of firms") label("DRT effect on quart 1." "P-valuequart 1 effect." "DRT effect on quart 2." "P-value quart 2 effect." "DRT effect on quart 3." "P-value quart 3 effect." "DRT effect on quart 4." "P-value quart 4 effect."))  /* 
*/ keep(drtown   _Idr*  )   indicate("YearDummy = _It_19*"  "YearDum*SizeClass =  _Ic*"   "Statetrend*SizeClass = _Is*   ")  
 

local verynew=""
local new =""
local testclass = ""
 














estimates clear
foreach y of varlist borrowing   /*
 */ assets   pbdt  {



 
local i = 4

 

set more off
  xtile sizeclass=Lassets if t==1990, nq(4)
     bys bid: egen x=max(sizeclass)
     drop sizeclass
     rename x class
 
run xi35.txt, nostop

 


xtreg `y' drtown   _Idr*  _It_*  _Ic*  _Is*  if t>=firstregressionsyear &t<=lastregressionsyear , fe cluster(bid)

estadd scalar class1  = _b[drtown]
 test drtown= 0
estadd scalar F_class1 = r(F) 


estadd scalar p_class1 = r(p)

forvalues j = 2(1)`i'{
estadd scalar class`j'  = _b[drtown] + _b[   _IdrXcl`j']

test _b[drtown] + _b[ _IdrXcl`j'] = 0

estadd scalar F_class`j' = r(F) 

estadd scalar p_class`j' = r(p)

}

estadd scalar numberofgroups = e(N_g) 
estimates store np`k'`y'2


drop class
 

}

forvalues j = 1(1)4{
local verynew="class`j' p_class`j' "
local new = "`testclass'"
local testclass =   "`new' `verynew'"
}

 label var drtown "DRT"
 
 
label var _IdrXcl2 "DRT*quart=2"
label var _IdrXcl`j'3 "DRT*quart=3"
label var _IdrXcl`j'4 "DRT*quart=4"

 


esttab  *  using borrowerlevelclustering.csv,  replace  /* 
*/   label star(* 0.10 ** 0.05 *** 0.01)title(Borrower level clsutering.\label{t5a})/*
 */ addnote("Standard errors are clustered at the borrower-level. All regressions use borrower fixed effects.")/*   
*/ stats(`testclass' numberofgroups  r2 N , layout(@ `"(@)"' @ `"(@)"' @ `"(@)"' @ `"(@)"' "number of firms") label("DRT effect on quart 1." "P-valuequart 1 effect." "DRT effect on quart 2." "P-value quart 2 effect." "DRT effect on quart 3." "P-value quart 3 effect." "DRT effect on quart 4." "P-value quart 4 effect."))  /* 
*/ keep(drtown   _Idr*  )   indicate("YearDummy = _It_19*"  "YearDum*SizeClass =  _Ic*"   "Statetrend*SizeClass = _Is*   ")  
 

local verynew=""
local new =""
local testclass = ""
 



